Module mp4

Module mp4 

Functions

detect_audio_track
Attempts to find the first audio track in the MP4 and map its sample entry to an AudioType.
is_m4a
Quick detection of M4A container via ftyp box. Works with moov at the end - only needs the first ~32 bytes.
is_mp4
Returns true if the data starts with a valid MP4 ftyp box.